# Mephisto

[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![code style: prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg)](https://github.com/prettier/prettier)

Mephisto makes crowdsourcing easier.

We provide a platform for launching, monitoring, and reviewing your crowdsourcing tasks. Tasks made on Mephisto can easily be open sourced as part of other projects.

As of now we're in an early alpha release, more details to come.

## Quickstart

[Get started in 10 minutes][quickstart]

## Changelog

## Want to help?

Check out our [guidelines for contributing](https://github.com/facebookresearch/Mephisto/blob/main/CONTRIBUTING.md) and then take a look at some of our tagged issues: [good first issue](https://github.com/facebookresearch/Mephisto/labels/good%20first%20issue), [help wanted](https://github.com/facebookresearch/Mephisto/labels/help%20wanted).

For library authors, you may also find the [development documentation][development] helpful.

[quickstart]: https://github.com/facebookresearch/mephisto/blob/main/docs/quickstart.md
[development]: https://github.com/facebookresearch/mephisto/blob/main/docs/development.md


## License
Mephisto is MIT licensed. See the LICENSE file for details.
